@@ -10,8 +10,8 @@ def send_help_message():
     message = request.json['message']
 
     if 'server' in local.config and 'support_email' not in local.config['server']:
-        print >>sys.stderr, 'Warning: No support_email configured, so no email sent.'
-        print >>sys.stderr, 'User\'s message: %s' % message
+        print('Warning: No support_email configured, so no email sent.', file=sys.stderr)
+        print('User\'s message: %s' % message, file=sys.stderr)
         return
 
     support_email = local.config['server']['support_email']
